package cn.fw.valhalla.controller.app;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.annotation.IgnoreAuth;
import cn.fw.security.auth.client.enums.AuthType;
import cn.fw.valhalla.domain.query.StammkundeAnalyseQueryVO;
import cn.fw.valhalla.domain.vo.customer.StammkundeAddressAnalyseVO;
import cn.fw.valhalla.domain.vo.customer.StammkundeAnalyseVO;
import cn.fw.valhalla.service.bus.StammkundeBizService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author : kurisu
 * @className : StammkundeController
 * @description : 保有客分析控制器
 * @date: 2021-01-21 15:28
 */
@Slf4j
@RestController
@Authorization(AuthType.APP)
@RequiredArgsConstructor
@Validated
@RequestMapping("/app/stammkunde")
public class StammkundeController {
    private final StammkundeBizService stammkundeBizService;

    /**
     * 根据关单任务对保有客地址进行分析
     *
     * @param queryVO
     * @return
     */
    @GetMapping("/address/analyse/task")
    @IgnoreAuth
    @ControllerMethod("根据关单任务对保有客地址进行分析")
    public Message<List<StammkundeAddressAnalyseVO>> taskAddressList(final StammkundeAnalyseQueryVO queryVO) {
        return success(stammkundeBizService.taskAddressList(queryVO));
    }

    /**
     * 对保有客地址进行分析
     *
     * @param queryVO
     * @return
     */
    @GetMapping("/address/analyse/customer")
    @IgnoreAuth
    @ControllerMethod("对保有客地址进行分析")
    public Message<List<StammkundeAddressAnalyseVO>> stammkundeAddressList(final StammkundeAnalyseQueryVO queryVO) {
        return success(stammkundeBizService.customerAddressList(queryVO));
    }

    /**
     * 对保有客地址进行热力图分析
     *
     * @param queryVO
     * @return
     */
    @GetMapping("/address/heatmap")
    @IgnoreAuth
    @ControllerMethod("对保有客地址进行热力图分析")
    public Message<List<StammkundeAnalyseVO>> stammkundeHeatmap(final StammkundeAnalyseQueryVO queryVO) {
        return success(stammkundeBizService.allCustomerList(queryVO));
    }

    /**
     * 查询半径范围内的客户
     *
     * @param queryVO
     * @return
     */
    @GetMapping("/distance/analyse")
    @IgnoreAuth
    @ControllerMethod("查询半径范围内的客户")
    public Message<List<StammkundeAnalyseVO>> stammkundeList(final StammkundeAnalyseQueryVO queryVO) {
        return success(stammkundeBizService.stammkundeList(queryVO));
    }
}
